#include "key2.h"

/** <code>
 * @file key2.c
 * @author M.Ruoss
 * 
 * @section KeyKapitel Tastenfunktionen
 * Saemtliche Funktionen zur nutzung des 4x4 Tastenfeldes.
 * @subsection KeyBeschreibung Beschreibung
 * Es werden zwei Funktionen bereit gestellt, zur Nutzung des Tastenfeldes.
 * Die erste Funktion wird zur Schnittstellen initialisierung benoetigt 
 * @ref keysetup() .
 * Die zweite Funktion wertet aus, ob eine Taste gedrueckt wurde @ref getKey() .
 * 
 * </code>
 */

/** <code>
 * Definieren von Makro fuer die Spalten1
 * </code> @note Makro zur Steuerung der Zeilen/Spalte mit hilfe des BIT_X Makros aus der plib.h
 */
#define Spalte1 BIT_6
/** <code>
 * Definieren von Makro fuer die Spalten2
 * </code> @note Makro zur Steuerung der Zeilen/Spalte mit hilfe des BIT_X Makros aus der plib.h
 */
#define Spalte2 BIT_4
/** <code>
 * Definieren von Makro fuer die Spalten3
 * </code> @note Makro zur Steuerung der Zeilen/Spalte mit hilfe des BIT_X Makros aus der plib.h
 */
#define Spalte3 BIT_3
/** <code>
 * Definieren von Makro fuer die Spalten4
 * </code> @note Makro zur Steuerung der Zeilen/Spalte mit hilfe des BIT_X Makros aus der plib.h
 */
#define Spalte4 BIT_2
/** <code>
 * Definieren von Makro fuer die Zeilen1
 * </code> @note Makro zur Steuerung der Zeilen/Spalte mit hilfe des BIT_X Makros aus der plib.h
 */
#define Zeile1 BIT_10
/** <code>
 * Definieren von Makro fuer die Zeilen2
 * </code> @note Makro zur Steuerung der Zeilen/Spalte mit hilfe des BIT_X Makros aus der plib.h
 */
#define Zeile2 BIT_9
/** <code>
 * Definieren von Makro fuer die Zeilen3
 * </code> @note Makro zur Steuerung der Zeilen/Spalte mit hilfe des BIT_X Makros aus der plib.h
 */
#define Zeile3 BIT_8
/** <code>
 * Definieren von Makro fuer die Zeilen4
 * </code> @note Makro zur Steuerung der Zeilen/Spalte mit hilfe des BIT_X Makros aus der plib.h
 */
#define Zeile4 BIT_7

volatile int result;

/** <code>
 * Initialisierung der Eingaenge fuer die Tastenmatrix abfrage.
 * Saemtliche Eingaenge und Ausgaenge werden mit den Makros
 * 
 * @ref Spalte1
 * @ref Spalte2
 * @ref Spalte3
 * @ref Spalte4
 * und 
 * @ref Zeile1
 * @ref Zeile2
 * @ref Zeile3
 * @ref Zeile4
 * 
 * richtig konfiguriert.
 * </code> @note siehe Details @ref key2.c Codeanzeige
 */
void keysetup()
{
    /* Key Ports Konfigurieren
     * Zeilen Port als Eingaenge
     * JA Pin 7-10
     */
    //PORTSetPinsDigitalIn (PORTB, Zeile4 | Zeile3 | Zeile2 | Zeile1 );
    mPORTBSetPinsDigitalIn(Zeile4 | Zeile3 | Zeile2 | Zeile1);
    /* Spalten als Ausgaenge
     * JA Pin 1-4
     */
    //PORTSetPinsDigitalOut (PORTB, Spalte4 | Spalte3 | Spalte2 | Spalte1);
    mPORTBSetPinsDigitalOut(Spalte4 | Spalte3 | Spalte2 | Spalte1);
    //PORTWrite (PORTB, Spalte4 | Spalte3 | Spalte2 | Spalte1 );
    mPORTBSetBits(Spalte4 | Spalte3 | Spalte2 | Spalte1);
}

/** <code>
 * Funktion liefert den Wert der gedrueckten Tasten zurueck.
 * @return int @ref result
 * Der Rueckgabewert entspricht der gedrueckten Taste
 * 
 *   @ref main.c
 * </code> @note siehe Detail @ref key2.c Codeanzeige
 */

int getKey(void)
{
    /*Lauf Variable i fuer for() Schleife
     */
    uint32_t i = 1;
    /*
     * for() welche welche die Umschaltung der einzelnen Spalten steuert
     */
    for (i; i <= 4; i++)
    {
        /* Auswerte Struktur mit einer Switch Case
         * Jedes Case repraesentiert eine Spalte, in der jeweils die einzelnen 
         * Zeilen ausgelesen werden und der Tasten Druck ermittelt wird. Dieser
         * mit result zurueck gemeldet
         * Am ende jeden Cases wir die Spalte wieder auf HIGH geschalten um eine 
         * Fehleingabe zu verhindern
         * Es werden keine Mehrtasten Eingaben unterstuetzt
         */
        switch (i)
        {
            /*Spalte1 auf LOW schalten*/
        case 1: PORTClearBits(IOPORT_B, Spalte1);
            /*Abfrage Taste 1
             */
            if (PORTReadBits(IOPORT_B, Zeile1) == 0)
            {
                /*Spalte 1*/
                PORTSetBits(IOPORT_B, Spalte1);
                return result=key1;
            }
            /*Abfrage Taste 4
             */
            if (PORTReadBits(IOPORT_B, Zeile2) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte1);
                return result = key4;
            }
            /*Abfrage Taste 7
             */
            if (PORTReadBits(IOPORT_B, Zeile3) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte1);
                return result = key7;
            }
            /*Abfrage Taste 0
             */
            if (PORTReadBits(IOPORT_B, Zeile4) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte1);
                return result = keyNull;
            }
            else
            {
                /*Spalte1 wieder auf HIGH setzen
                 */
                PORTSetBits(IOPORT_B, Spalte1);
            }
            break;
        case 2: PORTClearBits(IOPORT_B, Spalte2);
            /*Abfrage Taste 2
             */
            if (PORTReadBits(IOPORT_B, Zeile1) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte2);
                return result = key2;
            }
            /*Abfrage Taste 5
             */
            if (PORTReadBits(IOPORT_B, Zeile2) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte2);
                return result = key5;
            }
            /*Abfrage Taste 8
             */
            if (PORTReadBits(IOPORT_B, Zeile3) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte2);
                return result = key8;
            }
            /*Abfrage Taste F
             */
            if (PORTReadBits(IOPORT_B, Zeile4) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte2);
                return result = keyF;
            }
            else
            {
                /*Spalte2 wieder auf HIGH setzen
                 */
                PORTSetBits(IOPORT_B, Spalte2);
            }
            break;

        case 3: PORTClearBits(IOPORT_B, Spalte3);
            /*Abfrage Taste 3
             */
            if (PORTReadBits(IOPORT_B, Zeile1) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte3);
                return result = key3;
            }
            /*Abfrage Taste 6
             */
            if (PORTReadBits(IOPORT_B, Zeile2) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte3);
                return result = key6;
            }
            /*Abfrage Taste 9
             */
            if (PORTReadBits(IOPORT_B, Zeile3) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte3);
                return result = key9;
            }
            /*Abfrage Taste E
             */
            if (PORTReadBits(IOPORT_B, Zeile4) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte3);
                return result = keyE;
            }
            else
            {
                /*Spalte3 wieder auf HIGH setzen
                 */
                PORTSetBits(IOPORT_B, Spalte3);
            }
            break;

        case 4: PORTClearBits(IOPORT_B, Spalte4);
            /*Abfrage Taste A
             */
            if (PORTReadBits(IOPORT_B, Zeile1) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte4);
                return result = keyA;
            }
            /*Abfrage Taste B
             */
            if (PORTReadBits(IOPORT_B, Zeile2) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte4);
                return result = keyB;
            }
            /*Abfrage Taste C
             */
            if (PORTReadBits(IOPORT_B, Zeile3) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte4);
                return result = keyC;
            }
            /*Abfrage Taste D
             */
            if (PORTReadBits(IOPORT_B, Zeile4) == 0)
            {
                PORTSetBits(IOPORT_B, Spalte4);
                return result = keyD;
            }
            else
            {
                /*Spalte4 wieder auf HIGH setzen
                 */
                PORTSetBits(IOPORT_B, Spalte4);
            }

            break;
        default: return result = keyNoPress;
            break;

        }
    }

/*Keine Taste gedrueckt ->ergibt einen Rueckgabewert von -1
 */
    return result = keyNoPress;
}
