/* 
 * File:   main.c
 * Author: michel.ruoss
 *
 * Created on 10. Dezember 2015, 14:38
 */

/** <code>
 * @file main.c
 * @author M.Ruoss
 * 
 * @section MainKapitel Main Routine
 * Die Hauptfunktion des Programms.
 * @subsection MainBeschreibung Beschreibung
 * Hauptprogramm Ablauf besteht im aufruf der jeweiligen Menufunktion
 * Kontrolliert mit hilfe der MenuFlag Variable @ref menuFlag
 * in einer Switch Case Struktur
 * 
 * @see @ref  main()
 * 
 * </code>
 */
// Cerebot board configuration

#pragma config ICESEL       = ICS_PGx1  // ICE/ICD Comm Channel Select
#pragma config DEBUG        = OFF       // Debugger Disabled for Starter Kit
#pragma config FNOSC        = PRIPLL	// Oscillator selection
#pragma config POSCMOD      = XT	// Primary oscillator mode
#pragma config FPLLIDIV     = DIV_2	// PLL input divider
#pragma config FPLLMUL      = MUL_20	// PLL multiplier
#pragma config FPLLODIV     = DIV_1	// PLL output divider
#pragma config FPBDIV       = DIV_8	// Peripheral bus clock divider
#pragma config FSOSCEN      = OFF	// Secondary oscillator enable
#pragma config CP           = OFF       //Code Protection OFF

#define SYS_FREQ        (80000000)
#define getPBClock() (10000000)

/** <code>
 * Unterdruecken eines Warnhinweise zur nutzung der plib.h
 * </code> @note Warnhinweis wird in Outputfenster IDE unterdrueckt
 */
#define _SUPPRESS_PLIB_WARNING 1
#include <xc.h>
#include <plib.h>
#include <stdio.h>
#include <stdlib.h>
#include <stdbool.h>
#include "key2.h"
#include "systemkonf.h"
#include "PmodOLED.h"
#include "OledChar.h"
#include "OledGrph.h"
#include "Menu.h"
#include "MenuRed.h"
#include "MenuGreen.h"
#include "MenuBlue.h"
/** <code>
 * Menu SteuerungsFlag
 * </code> @note @ref Menu
 */
extern volatile int menuFlag;
/** <code>
 * Initialisierung des Menu Flags mit @ref menuFlagRot
 * </code> @note @ref menuFlagRot
 */
volatile int menuFlag = menuFlagRot;

/** <code>
 * Hilfsvariablen zur Steuerung der LED
 * PWM Wert fuer Kanal 1
 * </code> @note Volatile deklariert um eine optimierung durch den Compiler zur Unterbinden
 */
volatile int PWMvalue1;
/** <code>
 * Hilfsvariablen zur Steuerung der LED
 * PWM Wert fuer Kanal 2
 * </code> @note Volatile deklariert um eine optimierung durch den Compiler zur Unterbinden
 */
volatile int PWMvalue2;
/** <code>
 * Hilfsvariablen zur Steuerung der LED
 * PWM Wert fuer Kanal 3
 * </code> @note Volatile deklariert um eine optimierung durch den Compiler zur Unterbinden
 */
volatile int PWMvalue3;
/** <code>
 * Hilfsvariablen zur Steuerung der LED
 * Zwischenspeicher PWM Wert
 * </code> @note Volatile deklariert um eine optimierung durch den Compiler zur Unterbinden
 */
volatile int PWMpreValueRed = 0;
/** <code>
 * Hilfsvariablen zur Steuerung der LED
 * Zwischenspeicher PWM Wert
 * </code> @note Volatile deklariert um eine optimierung durch den Compiler zur Unterbinden
 */
volatile int PWMpreValueGreen = 0;
/** <code>
 * Hilfsvariablen zur Steuerung der LED
 * Zwischenspeicher PWM Wert
 * </code> @note Volatile deklariert um eine optimierung durch den Compiler zur Unterbinden
 */
volatile int PWMpreValueBlue = 0;
/** <code>
 * Hilfsvariablen zur Steuerung der LED
 * Zwischenspeicher PWM Wert
 * </code> @note Volatile deklariert um eine optimierung durch den Compiler zur Unterbinden
 */
volatile int PWMValueRed = 0;
/** <code>
 * Hilfsvariablen zur Steuerung der LED
 * Zwischenspeicher PWM Wert
 * </code> @note Volatile deklariert um eine optimierung durch den Compiler zur Unterbinden
 */
volatile int PWMValueGreen = 0;
/** <code>
 * Hilfsvariablen zur Steuerung der LED
 * Zwischenspeicher PWM Wert
 * </code> @note Volatile deklariert um eine optimierung durch den Compiler zur Unterbinden
 */
volatile int PWMValueBlue = 0;
/*KeyValue
 *
 *
 * volatile uint32_t readKey;
 *  */
/** <code>
 * Tasten representierende Variable 
 * Ohne eingabe immer -1.
 * </code> @note Volatile deklariert um eine optimierung durch den Compiler zur Unterbinden
 */
volatile int key = -1;
/** <code>
 * Hilfsvariablen zur Anzeigen des eingestellten Wertes in Prozent auf dem Display
 * 
 * </code> @note Volatile deklariert um eine optimierung durch den Compiler zur Unterbinden
 */
volatile uint32_t prozentValue = 0;

/** <code>
 * char Array zum erstellen des Wertes fuer die Ausgabe im Display mit Hilfe von sprintf()
 * 
 * </code> @note Volatile deklariert um eine optimierung durch den Compiler zur Unterbinden
 */
volatile char Display[16];

void keysetup(void);
int getKey(void);
void delay(unsigned int);

/** <code>
 * Nach der initialisierung des System laeuft ein while loop ab welcher die entsprechende Menu
 * Funktion ausfuehrt.
 * Dieser wird mit Hilfe einer switch case struktur mit der Variable menuFlag @ref Menu ausgewaehrtet.
 * siehe auch @ref getKey
 * </code> 
 */
void main()
{
    unsigned short value;


    setupSystem();
    OledInit();

    PWMvalue1 = 3600; // 50% modulation
    PWMvalue2 = 1800; // 25% modulation
    PWMvalue3 = 7200; // 100% modulation

    keysetup();
    OledClearBuffer();
    OledSetCursor(0, 1);
    OledPutString("DA-RGB-SYSTEM");
    OledSetCursor(0, 2);
    OledPutString("Ver.0.1 M.Ruoss");
    OledUpdate();
    delay(15000);


    while (1)
    {
        switch (menuFlag)
        {
        case menuFlagRot: menuFlag = menured(menuFlag);
            break;
        case menuFlagGruen: menuFlag = menugreen(menuFlag);
            break;
        case menuFlagBlau: menuFlag = menublue(menuFlag);
            break;
        default: break;
        }

    }
}
//---------------------------------------------------------------------------------------------------------------

/** <code>
 * Interrupt zur Steuerung des PWM. mit einer Frequenz von 5 kHz.
 * </code>
 */
void __ISR(_TIMER_2_VECTOR, ipl7) T2Interrupt(void)
{
    PWMvalue1 = PWMValueRed;

    PWMvalue2 = PWMValueGreen;

    PWMvalue3 = PWMValueBlue;

    SetDCOC1PWM(PWMvalue1); // these functions send a new value (0 to 7200) to PWM modulation with some PWM value.
    SetDCOC2PWM(PWMvalue2); // interrupt will fire again 7200 counts later than now  = 200us. (at 5 khz)
    SetDCOC3PWM(PWMvalue3);
    mT2ClearIntFlag(); // clear this interrupt .

}

/** <code>
 * Einfache Delay Funktion
 * @param[in] count ist ein unsigned int und wird heruntergezaelt mit Hilfe einer While-Schleife
 * 
 * </code> @brief Delay Funktion einfach
 */
void delay(unsigned int count)
 {
     unsigned int tWait, tStart;
         
     tWait=(SYS_FREQ/2000)*count;        //    SYS_FREQ        (80000000)
     tStart=ReadCoreTimer();
     while((ReadCoreTimer()-tStart)<tWait);        // wait for the time to pass
 
 }
//-------------------------------------------------------------------------------------------------------------- 

