#include "systemkonf.h"

/** <code>
 * @file systemkonf.c
 * @author M.Ruoss
 * 
 * @section systemkonfKapitel Systemkonfiguration
 * Dokumentation des Grundsystem Setup`s
 * @subsection systemkonfBeschreibung Beschreibung
 * Es ist nur eine Funktion vorhanden. Diese Initialisiert das
 * Grundsetup fuer das System.
 * @li @ref  setupSystem(void)
 * 
 * Hierzu gehoeren das einstellen des CPU Taktes und das erlauben der 
 * Multiinterruptsystems so wie initialisieren und starten des Comparatoren Outputs mit 3 Kanaelen.
 * </code>
 */

/** <code>
* Setup Konfiguirationsfunktion, ohne Parameter oder Returnwert
 * Mehr Details @ref systemkonf.h
 * </code> 
 */
void setupSystem()
{
    int samplerate;
    SYSTEMConfigPerformance(72000000L); // This function sets the PB-Div to 1. Also optimises cache for 72Mhz etc..
    mOSCSetPBDIV(OSC_PB_DIV_8); // Therefore, configure the PB bus to run at 1/8 CPU Frequency
    // you may run at PBclk of 72Mhz if you like too (omit this step)
    // This will double the PWM frequency.
    INTEnableSystemMultiVectoredInt(); // make separate interrupts possible

    samplerate = SAMPLE_RATE;

    OpenOC1(OC_ON | OC_TIMER2_SRC | OC_PWM_FAULT_PIN_DISABLE, 0, 0); // init OC1 module, T2 =source 
    OpenOC2(OC_ON | OC_TIMER2_SRC | OC_PWM_FAULT_PIN_DISABLE, 0, 0); // init OC2 module, T2 =source(you could do more OCx)
    OpenOC3(OC_ON | OC_TIMER2_SRC | OC_PWM_FAULT_PIN_DISABLE, 0, 0);
    OpenTimer2(T2_ON | T2_PS_1_1 | T2_SOURCE_INT, FPB / samplerate); // init Timer2 mode and period reg (PR2)

    PR2 = FPB / samplerate - 1;

    mT2SetIntPriority(7); // you don't have to use ipl7, but make sure INT definition is the same as your choice here
    mT2ClearIntFlag(); // make sure no int will be pending until 7200 counts from this point.  
    mT2IntEnable(1); // allow T2 int

}